@@ -48,6 +48,11 @@
 #include "hpproto.h"
 #include "unixproto.h"
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
+#	define inter_module_get(s) symbol_get(s)
+#	define inter_module_put(s) symbol_put(s)
+#endif
+
 /* PROTOTYPES */
 int _cmhp_ioctl(struct inode *i, struct file *f, unsigned int cmd, 
                 unsigned long arg);
