@@ -21,9 +21,12 @@ Revision History:
 
 
 #include "CpqCiHlx.h"
-#ifdef CPQCI_X86_64
+#ifdef CPQCI_X86_64 
+#if LINUX_VERSION_CODE >= 0x020610
+#include <linux/compat.h>
+#else
 #include <asm/ioctl32.h>
-//#include <linux/compat.h>
+#endif
 #endif
 #include "CpqCiWrp.h"
 #include "CpqCiTyp.h"
@@ -54,7 +57,7 @@ void DbgDump(struct _CPQCIADAPTEROBJECT* Adapter, CPQCICONNECTION Connection);
 #define virt_to_page(v) MAP_NR(v)
 #endif
 
-#define CPQEFSVER	"7.4.0"
+#define CPQEFSVER	"7.5.0"
 
 #define STRINGIZE(x)	#x
 char kernel_version[] = "2.4.7-10smp";
@@ -67,8 +70,13 @@ static int cpqci_close(struct inode *i, struct file *f);
 static int cpqci_ioctl(struct inode *i, struct file *f, unsigned int cmd,
 		       unsigned long arg);
 #ifdef CPQCI_X86_64
+#if LINUX_VERSION_CODE >= 0x020610
+static long cpqci_compat_ioctl(struct file *f, unsigned int cmd, unsigned long arg);
+int cpqci_ioctl32_handler(struct file *file, unsigned int cmd, unsigned long arg);
+#else
 int cpqci_ioctl32_handler(unsigned int fd, unsigned int cmd, unsigned long arg, struct file *file);
 #endif
+#endif
 static int cpqci_mmap(struct file *f, struct vm_area_struct *vma);
 #if LINUX_VERSION_CODE < 0x020600
 void cpqci_intr(int irq, void *dev_id, struct pt_regs *regs);
@@ -111,6 +119,10 @@ static struct file_operations cpqci_ops = {
 	release:	cpqci_close,
 	ioctl:		cpqci_ioctl,
 	mmap:		cpqci_mmap,
+#if defined(CPQCI_X86_64) && LINUX_VERSION_CODE >= 0x020610
+	compat_ioctl:	cpqci_compat_ioctl,
+#endif
+
 };
 
 static struct miscdevice cpqci_miscdev = {
@@ -465,6 +477,7 @@ Return Value:
 	int status;
 	int register_status;
 	int irq_status;
+	int ret;
 	struct pci_dev *pd;
 
 	CPQCICONNECTIONEXTENSION *connectionExtension;
@@ -490,8 +503,7 @@ Return Value:
 	error = CpqCiSuccess;
 	adapter = NULL;
 
-#ifdef CPQCI_X86_64
-	int ret;
+#if defined(CPQCI_X86_64) && LINUX_VERSION_CODE < 0x020610
 	
 	ret = register_ioctl32_conversion(CPQCI_IOCTL_PHYSMEM_ALLOC, cpqci_ioctl32_handler);
 	ret |= register_ioctl32_conversion(CPQCI_IOCTL_PHYSMEM_FREE, cpqci_ioctl32_handler);
@@ -632,7 +644,7 @@ Return Value:
 
 void cleanup_module(void)
 {
-#ifdef CPQCI_X86_64
+#if defined(CPQCI_X86_64) && LINUX_VERSION_CODE < 0x020610
 	unregister_ioctl32_conversion(CPQCI_IOCTL_PHYSMEM_ALLOC);
 	unregister_ioctl32_conversion(CPQCI_IOCTL_PHYSMEM_FREE);
 	unregister_ioctl32_conversion(CPQCI_IOCTL_CREATE_CHANNEL);
@@ -738,7 +750,43 @@ int cpqci_close(struct inode *i, struct file *f) {
 }
 
 #ifdef CPQCI_X86_64
+#if LINUX_VERSION_CODE >= 0x020610
+static int do_cpqci_ioctl(struct file *f, unsigned int cmd, unsigned long arg)
+{
+        int ret;
+        lock_kernel();
+        ret = cpqci_ioctl(f->f_dentry->d_inode, f, cmd, arg);
+        unlock_kernel();
+        return ret;
+}
+
+static long cpqci_compat_ioctl(struct file *f, unsigned int cmd, unsigned long arg)
+{
+	switch (cmd) {
+		case CPQCI_IOCTL_PHYSMEM_ALLOC:
+		case CPQCI_IOCTL_PHYSMEM_FREE:
+		case CPQCI_IOCTL_CREATE_CHANNEL:
+		case CPQCI_IOCTL_OPEN_CHANNEL:
+		case CPQCI_IOCTL_REGISTER_WAITER:
+		case CPQCI_IOCTL_GET_INFO:
+			return cpqci_ioctl32_handler(f, cmd, arg);
+		case SEM_CREATE:
+		case SEM_DESTROY:
+		case SEM_UP:
+		case SEM_DOWN:
+		case SEM_DOWN_TIMER:
+		case SEM_GET_VALUE:
+		case SEM_SET_VALUE:
+			return do_cpqci_ioctl(f, cmd, arg);
+		default:
+			return -ENOIOCTLCMD;
+	}
+
+}
+int cpqci_ioctl32_handler(struct file *file, unsigned int cmd, unsigned long arg)
+#else
 int cpqci_ioctl32_handler(unsigned int fd, unsigned int cmd, unsigned long arg, struct file *file)
+#endif
 {
 	int err = 0;
 	int i = 0;
@@ -757,10 +805,14 @@ int cpqci_ioctl32_handler(unsigned int fd, unsigned int cmd, unsigned long arg,
 		err |= get_user(mh64.MemorySize, &mh32->MemorySize);
 		err |= get_user(mh64.Attributes, &mh32->Attributes);
 		if (err) return -EFAULT;
+#if LINUX_VERSION_CODE >= 0x020610
+		err = do_cpqci_ioctl(file, cmd, (unsigned long)&mh64);
+#else
 		old_fs = get_fs();
 		set_fs(KERNEL_DS);
 		err = sys_ioctl(fd, cmd, (unsigned long)&mh64);
 		set_fs(old_fs);
+#endif
 		break;
 	case CPQCI_IOCTL_CREATE_CHANNEL:
 	case CPQCI_IOCTL_OPEN_CHANNEL:
@@ -781,10 +833,14 @@ int cpqci_ioctl32_handler(unsigned int fd, unsigned int cmd, unsigned long arg,
 		err |= get_user(ub64.TimeOut, &ub32->TimeOut);
 		err |= get_user(ub64.Oshandle, &ub32->Oshandle);
 		if (err) return -EFAULT;
+#if LINUX_VERSION_CODE >= 0x020610
+		err = do_cpqci_ioctl(file, cmd, (unsigned long)&ub64);
+#else
 		old_fs = get_fs();
 		set_fs(KERNEL_DS);
 		err = sys_ioctl(fd, cmd, (unsigned long)&ub64);
 		set_fs(old_fs);
+#endif
 		break;
 	case SEM_CREATE: 
 	case SEM_DESTROY:
@@ -797,10 +853,14 @@ int cpqci_ioctl32_handler(unsigned int fd, unsigned int cmd, unsigned long arg,
 #ifdef IOCTL_GET_INFO
 	case CPQCI_IOCTL_GET_INFO:
 #endif
+#if LINUX_VERSION_CODE >= 0x020610
+		err = do_cpqci_ioctl(file, cmd, arg);
+#else
 		old_fs = get_fs();
 		set_fs(KERNEL_DS);
 		err = sys_ioctl(fd, cmd, arg);
 		set_fs(old_fs);
+#endif
 		
 
 break;
