@@ -26,8 +26,12 @@
 #include "cridc.h"
 #include "cridw_linux.h"
 #ifdef CRID_X86_64
+#if LINUX_VERSION_CODE >= 0x020610
+#include <linux/compat.h>
+#else
 #include <asm/ioctl32.h>
 #endif
+#endif
 
 #if LINUX_VERSION_CODE >= 0x020600
 MODULE_LICENSE("Proprietary");
@@ -55,8 +59,13 @@ static int crid_ioctl(struct inode* inode, struct file* fp, unsigned int cmd, un
 static int crid_open(struct inode* inode, struct file* filep);
 static int crid_close(struct inode* inode, struct file* filep);
 #ifdef CRID_X86_64
+#if LINUX_VERSION_CODE >= 0x020610
+static long crid_compat_ioctl(struct file *f, unsigned int cmd, unsigned long arg);
+int crid_ioctl32_handler(struct file *file, unsigned int cmd, unsigned long arg);
+#else
 int crid_ioctl32_handler(unsigned int fd, unsigned int cmd, unsigned long arg, struct file *file);
 #endif
+#endif
 
 //interrupt handler
 #if LINUX_VERSION_CODE < 0x020600
@@ -73,6 +82,9 @@ static struct file_operations crid_ops = {
 	ioctl:		crid_ioctl,     /* ioctl */		
 	open:		crid_open,	/* open */		
 	release: 	crid_close,	/* close */		
+#if defined(CRID_X86_64) && LINUX_VERSION_CODE >= 0x020610
+        compat_ioctl:   crid_compat_ioctl,
+#endif
 };						
 
 extern struct proc_dir_entry* crid_entry_print_crid;
@@ -183,8 +195,8 @@ int init_module(void)
 {
 
   	int err_type; 
-#ifdef CRID_X86_64
 	int ret;
+#if defined(CRID_X86_64) && LINUX_VERSION_CODE < 0x020610
 
 	ret = register_ioctl32_conversion((('Z'<<8)|0), crid_ioctl32_handler);
 	ret |= register_ioctl32_conversion((('Z'<<8)|1), crid_ioctl32_handler);
@@ -250,7 +262,7 @@ void cleanup_module(void)
 	//Unregister the driver at once, so that we have 
 	//clean break from agents.
 	unregister_chrdev(crid_major, "cpqrid");
-#ifdef CRID_X86_64
+#if defined(CRID_X86_64) && LINUX_VERSION_CODE < 0x020610
 	unregister_ioctl32_conversion((('Z'<<8)|0));
 	unregister_ioctl32_conversion((('Z'<<8)|1));
 	unregister_ioctl32_conversion((('Z'<<8)|2));
@@ -439,6 +451,37 @@ static int crid_close(struct inode* inode, struct file* filep)
 
 
 #ifdef CRID_X86_64
+#if LINUX_VERSION_CODE >= 0x020610
+static int do_crid_ioctl(struct file *f, unsigned int cmd, unsigned long arg)
+{
+        int ret;
+        lock_kernel();
+        ret = crid_ioctl(f->f_dentry->d_inode, f, cmd, arg);
+        unlock_kernel();
+        return ret;
+}
+
+static long crid_compat_ioctl(struct file *f, unsigned int cmd, unsigned long arg)
+{
+	switch (cmd) {
+		case (('Z'<<8)|0):
+		case (('Z'<<8)|1):
+		case (('Z'<<8)|2):
+		case (('Z'<<8)|3):
+		case (('Z'<<8)|4):
+		case (('Z'<<8)|5):
+		case (('Z'<<8)|6):
+		case (('Z'<<8)|7):
+		case (('Z'<<8)|8):
+		case (('Z'<<8)|9):
+		case (('Z'<<8)|0xA):
+		case (('Z'<<8)|0xC):
+		case (('Z'<<8)|0xD):
+			return crid_ioctl32_handler(f, cmd, arg);
+		default:
+			return -ENOIOCTLCMD;
+		}
+}
 /*********************************************************************
 
 @func  crid_ioctl32_handler
@@ -452,7 +495,10 @@ Return Value:
 
 
 ***********************************************************************/
+int crid_ioctl32_handler(struct file *file, unsigned int cmd, unsigned long arg)
+#else
 int crid_ioctl32_handler(unsigned int fd, unsigned int cmd, unsigned long arg, struct file *file)
+#endif
 {
 	int err = 0;
 	mm_segment_t old_fs;
@@ -480,17 +526,25 @@ int crid_ioctl32_handler(unsigned int fd, unsigned int cmd, unsigned long arg, s
 			err |= get_user(ioctl_arg64.resp_cmd, &ioctl_arg32->resp_cmd);
 			err |= get_user(ioctl_arg64.resp_length, &ioctl_arg32->resp_length);
 			if (err) return -EFAULT;
+#if LINUX_VERSION_CODE >= 0x020610
+                	err = do_crid_ioctl(file, cmd, (unsigned long)&ioctl_arg64);
+#else
 			old_fs = get_fs();
 			set_fs(KERNEL_DS);
 			err = sys_ioctl(fd, cmd, (unsigned long)&ioctl_arg64);
 			set_fs(old_fs);
+#endif
 			break;
 		case (('Z'<<8)|2):
 		case (('Z'<<8)|3):
+#if LINUX_VERSION_CODE >= 0x020610
+                	err = do_crid_ioctl(file, cmd, arg);
+#else
 			old_fs = get_fs();
 			set_fs(KERNEL_DS);
 			err = sys_ioctl(fd, cmd, arg);
 			set_fs(old_fs);
+#endif
 			break;
 	}
 	if(err == 0) {
@@ -1634,6 +1688,7 @@ Return Value:
 
 
 ***********************************************************************/
+#if 0
 
 int cridw_log_evt(int log, int match, int num, void* entry)
 {
@@ -1646,13 +1701,11 @@ int cridw_log_evt(int log, int match, int num, void* entry)
    iml_interface_t cpqwEventHandler = (iml_interface_t)inter_module_get(EVENT_LOG_HANDLER);
 
    if (!cpqwEventHandler) {
-#if 0
 	if(!displayed) {
 		printk(KERN_NOTICE "NOTICE: %s not registered. cpqevt module may not be loaded. Events will be not be logged.\n", 
 				EVENT_LOG_HANDLER);
 		displayed = 1;
 	}
-#endif
    	return 0;
    }
 
@@ -1660,6 +1713,7 @@ int cridw_log_evt(int log, int match, int num, void* entry)
    inter_module_put(EVENT_LOG_HANDLER);
    return rc;
 }
+#endif
 
 /*********************************************************************
 ** 
@@ -1675,6 +1729,7 @@ int cridw_log_evt(int log, int match, int num, void* entry)
 ** 1   : FAILURE
 ** 
 ***********************************************************************/
+#if 0
 int cridw_set_evthnd(void* evthnd)
 {
    //lets only display the message once
@@ -1697,6 +1752,7 @@ int cridw_set_evthnd(void* evthnd)
    inter_module_put(EVENT_CALLBACK);
    return 0;
 }
+#endif
 
 /*********************************************************************
 ** 
