@@ -75,22 +75,26 @@ PATH=/opt/compaq/foundation/bin:/opt/compaq/server/bin:/opt/compaq/hpasmd/bin:/o
 case "$1" in
   start)
 	$STARTADDON	
-	cmaechon "Starting $NAME ($PNAME): "
-	pidlist=`$PIDOF -o $$ $PNAME`
-	if [ -z "$pidlist" ]; then
-	  $PNAME $PFLAGS < /dev/null >> $LOGFILE 2>&1 &
-	  RETVAL=$?
-	else
-	  RETVAL=1
+	RETVAL=$?
+	if [ $RETVAL -eq 0 ]; then
+		cmaechon "Starting $NAME ($PNAME): "
+		pidlist=`$PIDOF -o $$ $PNAME`
+		if [ -z "$pidlist" ]; then
+	  		$PNAME $PFLAGS < /dev/null >> $LOGFILE 2>&1 &
+	  		RETVAL=$?
+		else
+	  		RETVAL=1
+		fi
 	fi
 	cmaecho
 	;;
   stop)
-	$STOPADDON
 	cmaechon "Shutting down $NAME ($PNAME): "
 	stopproc $PNAME 
 	RETVAL=$?
 	cmaecho
+	$STOPADDON
+	cmaecho
 	;;
   restart)
 	$0 stop
@@ -98,6 +102,8 @@ case "$1" in
 	RETVAL=$?
 	;;
   status)
+	$STATUSADDON
+	cmaecho
         pid=`$PIDOF -o $$ -o $PPID -o %PPID -x $PNAME`
         if [ -n "$pid" ]; then
                 echo "$PNAME is running..."
