@@ -74,6 +74,7 @@ set Options(CONNECT) 3
 set Options(CLEAR) 4
 set Options(APPEND) 5
 set Options(START) 6
+set Options(SIZE) 7
 
 set SEVER(Repaired)	6
 set SEVER(Information)	2
@@ -372,6 +373,19 @@ proc ParseIMLList {} {
 	}
 }
 
+proc GetImlSize {} {
+                                                                                                                           
+        global ImlSize InputPipe OutputPipe Options
+                                                                                                                           
+        # Grab the current size of the number of events
+        puts $InputPipe "$Options(SIZE)* * "
+        flush $InputPipe
+        if { [gets $OutputPipe retval] == -1} {
+           Quit $IML_GUI_MSGS(MSG_BROKEN_PIPE)
+        }
+        set ImlSize [lindex $retval 0]
+}
+
 proc CallBrowser {} {
 
 	global BRFile BROWSE URL
@@ -975,19 +989,46 @@ proc GetNameAndExitCancel { dialog } {
 }
 
 proc GetNameAndSaveExit { dialog} {
-	global IMLList IML_GUI_MSGS ClearLogRequired
+	global IMLList IML_GUI_MSGS ClearLogRequired ImlSize
 
 	set dialog_fsbox [$dialog subwidget fsbox]
 	set dialog_fsbox_selection [$dialog_fsbox subwidget selection]
+	set dialog_fsbox_filter [$dialog_fsbox subwidget filter]
 
 	set filename [$dialog_fsbox_selection cget -value]
+
+        # I need a check here for making sure the user is not
+        # attempting to save the .iml file on a read only
+        # file system.
+        set filter [$dialog_fsbox_filter cget -value]
+        set filter [string trimright $filter [list "/" "*"]]
+        set space [exec /bin/df $filter]
+        set space [lindex $space 10]
+
+        # Now let's get the latest update on the size of the IML
+        GetImlSize
+
 	if { $filename == "" } {
 		DisplayErrorMessage $IML_GUI_MSGS(MSG_ENTER_FILENAME)
 		return
+        } elseif { $space < $ImlSize } {
+                DisplayErrorMessage "Not enough room on $filter to save the current IML log."
+                return
+        } elseif { $space == 0 } {
+                DisplayErrorMessage "Unable to create the file. Check to make sure you are not on a Read-Only filesystem."
+                return
 	} else {
                 if {[string match *.iml* $filename] == 0} {
         	   append filename ".iml"
                 }
+
+                # If the user simply enters a filename and no path
+                # then we will at least prepend the filter path
+                # to successfully create the file.
+                if {[string index $filename 0] != "/"} {
+                   set filename "$filter/$filename"
+                }
+
         	set fd [open $filename w+]
         	seek $fd 0 end
         	set IMLListLength [llength $IMLList]
@@ -1003,10 +1044,10 @@ proc GetNameAndSaveExit { dialog} {
         tixPushGrab $dialog
 	tixPopGrab 
 	destroy $dialog
-	if { $ClearLogRequired == 1 } {
-		ClearLog
-		set ClearLogRequired 0
-	}
+	#if { $ClearLogRequired == 1 } {
+	#	ClearLog
+	#	set ClearLogRequired 0
+	#}
 }
 
 
@@ -1057,29 +1098,31 @@ proc GetNameAndOpenExit { dialog } \
 	set filename [$dialog_fsbox_selection cget -value]
 
 	if { $filename == "" } {
-		DisplayErrorMessage $IML_GUI_MSGS(MSG_ENTER_OPENNAME)
+        	DisplayErrorMessage $IML_GUI_MSGS(MSG_ENTER_OPENNAME)
 		return
+	} elseif { ![file exists $filename] } {
+		DisplayErrorMessage $IML_GUI_MSGS(MSG_FILE_NOT_FOUND)
+		return
+        } elseif { [string first .iml $filename] == -1 } {
+                DisplayErrorMessage "File $filename is not an .iml file. Please select a file with a .iml extension."
+                return
 	} else {
-		if { ![file exists $filename] } {
-			DisplayErrorMessage $IML_GUI_MSGS(MSG_FILE_NOT_FOUND)
-		} else {
-			set FileName "$filename"
-			set OldIml 1
-			set IMLList [list]
-			set FullIMLList [list]
-			set fd [open $filename]
-			set cont [gets $fd line]
-			while {$cont >= 0} {
-	 			set row [list]
-	   			for {set i 0} {$i < 7} {incr i} {
-					lappend row $line
-					set cont [gets $fd line]
-	 			}
-		 		lappend IMLList $row
-		 		lappend FullIMLList $row
-			}
-			close $fd
+		set FileName "$filename"
+		set OldIml 1
+		set IMLList [list]
+		set FullIMLList [list]
+		set fd [open $filename]
+		set cont [gets $fd line]
+		while {$cont >= 0} {
+ 			set row [list]
+  			for {set i 0} {$i < 7} {incr i} {
+				lappend row $line
+				set cont [gets $fd line]
+ 			}
+	 		lappend IMLList $row
+	 		lappend FullIMLList $row
 		}
+		close $fd
 	}
         tixPushGrab $dialog
 	tixPopGrab 
@@ -1405,13 +1448,13 @@ proc SortOptionsCB { } \
 	set m [radiobutton $w.f.radio5 \
 		-text "Sort by Initial Time" \
 		-variable Sort \
-		-value 4]
+		-value 5]
 	pack $m -side top -anchor w
 
 	set m [radiobutton $w.f.radio6 \
 		-text "Sort by Update Time" \
 		-variable Sort \
-		-value 5]
+		-value 4]
 	pack $m -side top -anchor w
 	
 	set m [radiobutton $w.f.radio7 \
@@ -1489,21 +1532,13 @@ proc CloseFile {} {
 # Rebuild the window title when viewing a file instead of the log.
 proc UpdateTitle {} {
 
-	global FileName form IML_GUI_MSGS HostName
+	global FileName form IML_GUI_MSGS 
 	
 	if { $FileName != "" } {
 		set newTitle "- "
 	}
 	append newTitle "$FileName"
-        if {[string match *debian* $HostName] != 0} {
-                set DriverInfo [exec dpkg -l hpasm | grep hpasm]
-                set DriverName [lindex $DriverInfo 1]
-                set Version [lindex $DriverInfo 2]
-                set DriverInfo "$DriverName-$Version"
-        } else {
-                set DriverInfo [exec rpm -q hpasm]
-        }
-
+	set DriverInfo [exec rpm -q hpasm]
 	wm title $form "$IML_GUI_MSGS(MSG_APP_TITLE) $DriverInfo $newTitle"
 }
 
@@ -1542,16 +1577,7 @@ set form .app
 catch {destroy $form}
 toplevel $form
 bind .app  <Destroy> exit 
-
-if {[string match *debian* $HostName] != 0} {
-   set DriverInfo [exec dpkg -l hpasm | grep hpasm ]
-   set DriverName [lindex $DriverInfo 1]
-   set Version [lindex $DriverInfo 2]
-   set DriverInfo "$DriverName-$Version"
-} else {
-   set DriverInfo [exec rpm -q hpasm]
-}
-
+set DriverInfo [exec rpm -q hpasm]
 wm title $form "$IML_GUI_MSGS(MSG_APP_TITLE) - $DriverInfo"
 wm iconname $form "menu"
 wm geometry $form 800x500+100+100
@@ -1707,6 +1733,7 @@ OpenCmdPipes
 SetToAll
 ParseAndUpdateList 1
 UpdateMenuOptions
+GetImlSize
 
 # Bindings for the menu tooltips.
 bind .app.menu <<MenuSelect>> {
