@@ -7,11 +7,6 @@ CS_SUPP=/opt/hp/support
 #
 #
 #
-## Create 'hpsmh' User and Group
-#
-#/usr/sbin/groupadd -g 79 hpsmh
-#/usr/sbin/useradd -u 79 -g 79 -s /sbin/nologin -M -r -d $CS_ROOT/hpsmh hpsmh
-#
 ## Create logs under /var/spool
 #
 if [ ! -d /var/spool/opt ]; then
@@ -45,17 +40,17 @@ if [[ $l_c != 0 ]]; then
    do
      read rline;
      thefile=${rline:0}
-     if [ -d $thefile ]; then
+     if [ -d "$thefile" ]; then
         chmod 750 $thefile > /dev/null 2>&1
-        chown 79:79 $thefile > /dev/null 2>&1
+        chown hpsmh:hpsmh $thefile > /dev/null 2>&1
      fi
    done <$fn
 fi
 rm -f /tmp/files.tmp
 chmod 750 /opt/hp > /dev/null 2>&1
-chown 79:79 /opt/hp > /dev/null 2>&1
-chmod 750 /opt/hp/sslshare > /dev/null 2>&1
-chown 79:79 /opt/hp/sslshare > /dev/null 2>&1
+chown hpmsh:hpsmh /opt/hp > /dev/null 2>&1
+chmod 750 /etc/opt/hp/sslshare > /dev/null 2>&1
+chown root:hspmh /etc/opt/hp/sslshare > /dev/null 2>&1
 #
 chown root:hpsmh $CS_WORK/sbin/cgi_pam
 chmod 4755 $CS_WORK/sbin/cgi_pam
